# raytils

![](https://github.com/RaymondKirk/raytils/workflows/build/badge.svg)

Suite of [my](https://github.com/RaymondKirk) utility packages for Python.

## Documentation

Please refer to the [documentation](https://raymondkirk.github.io/raytils/) for installation instructions and API usage.

## Citing Raytils


If you use raytils in your research please use the following BibTeX entry and any BibTeX entries for used functions.

```BibTeX
@misc{rk2020raytils,
  author =       {Raymond Kirk},
  title =        {raytils},
  howpublished = {\url{https://github.com/RaymondKirk/raytils}},
  year =         {2020}
}
```
